

# Module hex_api_key #
* [Data Types](#types)
* [Function Index](#index)
* [Function Details](#functions)

<a name="types"></a>

## Data Types ##




### <a name="type-api_permission">api_permission()</a> ###


<pre><code>
api_permission() = #{domain =&gt; api, resource =&gt; read | write}
</code></pre>




### <a name="type-permission">permission()</a> ###


<pre><code>
permission() = <a href="#type-api_permission">api_permission()</a> | <a href="#type-repo_permission">repo_permission()</a> | <a href="#type-repos_permission">repos_permission()</a>
</code></pre>




### <a name="type-repo_permission">repo_permission()</a> ###


<pre><code>
repo_permission() = #{domain =&gt; repository, resource =&gt; binary()}
</code></pre>




### <a name="type-repos_permission">repos_permission()</a> ###


<pre><code>
repos_permission() = #{domain =&gt; repositories}
</code></pre>

<a name="index"></a>

## Function Index ##


<table width="100%" border="1" cellspacing="0" cellpadding="2" summary="function index"><tr><td valign="top"><a href="#add-3">add/3</a></td><td>
Adds a new API or repository key.</td></tr><tr><td valign="top"><a href="#delete-2">delete/2</a></td><td>
Deletes an API or repository key.</td></tr><tr><td valign="top"><a href="#delete_all-1">delete_all/1</a></td><td>
Deletes all API and repository keys associated with the account.</td></tr><tr><td valign="top"><a href="#get-2">get/2</a></td><td>
Gets an API or repository key by name.</td></tr><tr><td valign="top"><a href="#list-1">list/1</a></td><td>
Lists the user's or organization's API and repository keys.</td></tr></table>


<a name="functions"></a>

## Function Details ##

<a name="add-3"></a>

### add/3 ###

<pre><code>
add(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, Name::binary(), Permissions::[<a href="#type-permission">permission()</a>]) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Adds a new API or repository key.

Examples:

```
  > hex_api_key:add(hex_core:default_config(), <<"test">>, [...]).
  {ok, {200, ..., #{
      <<"authing_key">> => true,
      <<"inserted_at">> => <<"2019-02-27T11:15:32Z">>,
      <<"last_use">> =>
          #{<<"ip">> => <<"1.2.3.4">>,
            <<"used_at">> => <<"2019-02-27T14:38:54Z">>,
            <<"user_agent">> => <<"hex_core/0.5.0 (httpc) (OTP/21) (erts/10.2)">>},
      <<"name">> => <<"hex_core">>,
      <<"permissions">> => [#{<<"domain">> => <<"api">>,<<"resource">> => <<"read">>}],
      <<"revoked_at">> => nil,
      <<"updated_at">> => <<"2019-02-27T14:38:54Z">>,
      <<"url">> => <<"https://hex.pm/api/keys/test">>},
      }}}
```

<a name="delete-2"></a>

### delete/2 ###

<pre><code>
delete(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, Name::binary()) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Deletes an API or repository key.

Examples:

```
  > hex_api_key:delete(hex_core:default_config(), <<"test">>).
  {ok, {200, ..., #{
      <<"authing_key">> => true,
      <<"inserted_at">> => <<"2019-02-27T11:15:32Z">>,
      <<"last_use">> =>
          #{<<"ip">> => <<"1.2.3.4">>,
            <<"used_at">> => <<"2019-02-27T14:38:54Z">>,
            <<"user_agent">> => <<"hex_core/0.5.0 (httpc) (OTP/21) (erts/10.2)">>},
      <<"name">> => <<"hex_core">>,
      <<"permissions">> => [#{<<"domain">> => <<"api">>,<<"resource">> => <<"read">>}],
      <<"revoked_at">> => nil,
      <<"updated_at">> => <<"2019-02-27T14:38:54Z">>,
      <<"url">> => <<"https://hex.pm/api/keys/test">>},
      }}}
```

<a name="delete_all-1"></a>

### delete_all/1 ###

<pre><code>
delete_all(Config::<a href="hex_core.md#type-config">hex_core:config()</a>) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Deletes all API and repository keys associated with the account.

Examples:

```
  > hex_api_key:delete_all(hex_core:default_config()).
  {ok, {200, ..., [#{
      <<"authing_key">> => true,
      <<"inserted_at">> => <<"2019-02-27T11:15:32Z">>,
      <<"last_use">> =>
          #{<<"ip">> => <<"1.2.3.4">>,
            <<"used_at">> => <<"2019-02-27T14:38:54Z">>,
            <<"user_agent">> => <<"hex_core/0.5.0 (httpc) (OTP/21) (erts/10.2)">>},
      <<"name">> => <<"hex_core">>,
      <<"permissions">> => [#{<<"domain">> => <<"api">>,<<"resource">> => <<"read">>}],
      <<"revoked_at">> => nil,
      <<"updated_at">> => <<"2019-02-27T14:38:54Z">>,
      <<"url">> => <<"https://hex.pm/api/keys/test">>},
      }]}}
```

<a name="get-2"></a>

### get/2 ###

<pre><code>
get(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, Name::binary()) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Gets an API or repository key by name.

Examples:

```
  > hex_api_key:get(hex_core:default_config(), <<"test">>).
  {ok, {200, ..., #{
      <<"authing_key">> => true,
      <<"inserted_at">> => <<"2019-02-27T11:15:32Z">>,
      <<"last_use">> =>
          #{<<"ip">> => <<"1.2.3.4">>,
            <<"used_at">> => <<"2019-02-27T14:38:54Z">>,
            <<"user_agent">> => <<"hex_core/0.5.0 (httpc) (OTP/21) (erts/10.2)">>},
      <<"name">> => <<"hex_core">>,
      <<"permissions">> => [#{<<"domain">> => <<"api">>,<<"resource">> => <<"read">>}],
      <<"revoked_at">> => nil,
      <<"updated_at">> => <<"2019-02-27T14:38:54Z">>,
      <<"url">> => <<"https://hex.pm/api/keys/test">>},
      }}}
```

<a name="list-1"></a>

### list/1 ###

<pre><code>
list(Config::<a href="hex_core.md#type-config">hex_core:config()</a>) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Lists the user's or organization's API and repository keys.

Examples:

```
  > hex_api_key:list(hex_core:default_config()).
  {ok, {200, ..., [#{
      <<"authing_key">> => true,
      <<"inserted_at">> => <<"2019-02-27T11:15:32Z">>,
      <<"last_use">> =>
          #{<<"ip">> => <<"1.2.3.4">>,
            <<"used_at">> => <<"2019-02-27T14:38:54Z">>,
            <<"user_agent">> => <<"hex_core/0.5.0 (httpc) (OTP/21) (erts/10.2)">>},
      <<"name">> => <<"hex_core">>,
      <<"permissions">> => [#{<<"domain">> => <<"api">>,<<"resource">> => <<"read">>}],
      <<"revoked_at">> => nil,
      <<"updated_at">> => <<"2019-02-27T14:38:54Z">>,
      <<"url">> => <<"https://hex.pm/api/keys/test">>},
      }]}}
```

