

# Module hex_api_organization_member #
* [Data Types](#types)
* [Function Index](#index)
* [Function Details](#functions)

<a name="types"></a>

## Data Types ##




### <a name="type-role">role()</a> ###


<pre><code>
role() = admin | write | read
</code></pre>

<a name="index"></a>

## Function Index ##


<table width="100%" border="1" cellspacing="0" cellpadding="2" summary="function index"><tr><td valign="top"><a href="#add-3">add/3</a></td><td>
Adds an organization member.</td></tr><tr><td valign="top"><a href="#delete-2">delete/2</a></td><td>
Deletes an organization member.</td></tr><tr><td valign="top"><a href="#get-2">get/2</a></td><td>
Gets an organization member.</td></tr><tr><td valign="top"><a href="#list-1">list/1</a></td><td>
Lists the organization's members.</td></tr><tr><td valign="top"><a href="#update-3">update/3</a></td><td>
Updates an organization member's role.</td></tr></table>


<a name="functions"></a>

## Function Details ##

<a name="add-3"></a>

### add/3 ###

<pre><code>
add(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, UsernameOrEmail::binary(), Role::<a href="#type-role">role()</a>) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Adds an organization member.

Examples:

```
  > hex_api_organization_member:add(hex_core:default_config()#{api_organization => <<"acme">>}, <<"user">>, write).
  {ok, {200, ..., #{
       <<"email">> => <<"user@example.com">>,
       <<"role">> => <<"write">>,
       <<"url">> => <<"https://hex.pm/api/users/user">>,
       <<"username">> => <<"user">>
       }}}
```

<a name="delete-2"></a>

### delete/2 ###

<pre><code>
delete(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, UsernameOrEmail::binary()) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Deletes an organization member.

Examples:

```
  > hex_api_organization_member:delete(hex_core:default_config()#{api_organization => <<"acme">>}, <<"user">>).
  {ok, {204, ..., nil}}
```

<a name="get-2"></a>

### get/2 ###

<pre><code>
get(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, UsernameOrEmail::binary()) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Gets an organization member.

Examples:

```
  > hex_api_organization_member:get(hex_core:default_config()#{api_organization => <<"acme">>}, <<"user">>).
  {ok, {200, ..., #{
       <<"email">> => <<"user@example.com">>,
       <<"role">> => <<"admin">>,
       <<"url">> => <<"https://hex.pm/api/users/user">>,
       <<"username">> => <<"user">>
       }}}
```

<a name="list-1"></a>

### list/1 ###

<pre><code>
list(Config::<a href="hex_core.md#type-config">hex_core:config()</a>) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Lists the organization's members.

Examples:

```
  > hex_api_organization_member:list(hex_core:default_config()#{api_organization => <<"acme">>}).
  {ok, {200, ..., [#{
       <<"email">> => <<"user@example.com">>,
       <<"role">> => <<"admin">>,
       <<"url">> => <<"https://hex.pm/api/users/user">>,
       <<"username">> => <<"user">>
       }]}}
```

<a name="update-3"></a>

### update/3 ###

<pre><code>
update(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, UsernameOrEmail::binary(), Role::<a href="#type-role">role()</a>) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Updates an organization member's role.

Examples:

```
  > hex_api_organization_member:update(hex_core:default_config()#{api_organization => <<"acme">>}, <<"user">>, read).
  {ok, {200, ..., #{
       <<"email">> => <<"user@example.com">>,
       <<"role">> => <<"read">>,
       <<"url">> => <<"https://hex.pm/api/users/user">>,
       <<"username">> => <<"user">>
       }}}
```

